<?php
/**
 * Travelia Footer Settings panel at Theme Customizer
 *
 * @package Travelia
 * @since 1.0.0
 */

add_action( 'customize_register', 'travelia_footer_settings_register' );

function travelia_footer_settings_register( $wp_customize ) {

	/**
     * Add Footer Settings Panel
     *
     * @since 1.0.0
     */
  $wp_customize->add_panel(
   'travelia_footer_settings_panel',
   array(
     'priority'       => 30,
     'capability'     => 'edit_theme_options',
     'theme_supports' => '',
     'title'          => __( 'Footer Settings', 'travelia-pro' ),
   )
 );




  /*----------------------------------------------------------------------------------------------------------------------------------------*/
  /**
     * Footer Top section
     *
     * @since 1.0.0
     */
  $wp_customize->add_section(
    'travelia_footer_top_section',
    array(
      'priority'       => 2,
      'panel'          => 'travelia_footer_settings_panel',
      'capability'     => 'edit_theme_options',
      'theme_supports' => '',
      'title'          => __( 'Footer Top Section', 'travelia-pro' ),
      'description'    => __( 'Managed the content display at Footer Top section.', 'travelia-pro' ),
    )
  );

/**
 * Enable/Disable for footer top
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
  'travelia_footer_top_enable',
  array(
    'default'           => 0,
    'sanitize_callback' => 'travelia_sanitize_checkbox',
  )
);

$wp_customize->add_control(
  'travelia_footer_top_enable',
  array(
    'section'     => 'travelia_footer_top_section',
    'label'       => __( 'Enable/Disable for Footer Top Newsletter', 'travelia-pro' ),
    'type'        => 'checkbox'
  )       
);
class Widget_Page_link extends WP_Customize_Control {
  public $type = 'customtext';
    public $extra = ''; // we add this for the extra description
    public function render_content() {
      ?>
      <label>            
        <a href="<?php echo esc_url( 'widgets.php' ); ?>" target='_blank'><?php echo esc_html( $this->label ); ?></a>
        <span><?php echo esc_html( $this->extra ); ?></span>         
      </label>
      <?php
    }
  }
  $wp_customize->add_setting('travelia_go_to_widget', array(
    'default' => '',
    'type' => 'customtext',
    'capability' => 'edit_theme_options',
    'transport' => 'refresh',
    'sanitize_callback' => 'sanitize_text_field',
  ) );
  $wp_customize->add_control( new Widget_Page_link( $wp_customize, 'travelia_go_to_widget', array(
    'label' => esc_attr__( 'Go to Widgets Page', 'travelia-pro' ),
    'section' => 'travelia_footer_top_section',
    'settings' => 'travelia_go_to_widget',
    'extra' => esc_attr__( 'click here', 'travelia-pro' )
  ) ) 
);


  /*----------------------------------------------------------------------------------------------------------------------------------------*/
  /**
     * Footer Bottom section
     *
     * @since 1.0.0
     */
  $wp_customize->add_section(
    'travelia_footer_bottom_section',
    array(
      'priority'       => 3,
      'panel'          => 'travelia_footer_settings_panel',
      'capability'     => 'edit_theme_options',
      'theme_supports' => '',
      'title'          => __( 'Footer Bottom Section', 'travelia-pro' ),
      'description'    => __( 'Managed the content display at Footer Bottom section.', 'travelia-pro' ),
    )
  );

  /**Footer Copyright Text */
  $wp_customize->add_setting(
    'travelia_footer_copyright_text',
    array(
      'default'           => __( 'Copyright &copy; 2018 MyWordPress Themes, Inc. All rights reserved.', 'travelia-pro' ),
      'sanitize_callback' => 'sanitize_text_field',
      'transport'         => 'postMessage'
    )
  );

  $wp_customize->add_control(
    'travelia_footer_copyright_text',
    array(
      'label'    => __( 'Footer Copyright text', 'travelia-pro' ),
      'section'  => 'travelia_footer_bottom_section',
      'type'     => 'text',
    )
  );

  $wp_customize->selective_refresh->add_partial( 'travelia_footer_copyright_text', array(
    'selector' => '.footer-bottom .copyright p',
    'render_callback' => 'travelia_footer_copyright_get_links_text',
  ) );

}