<?php
/**
 * Travelia Pages Settings panel at Theme Customizer
 *
 * @package Travelia
 * @since 1.0.0
 */

add_action( 'customize_register', 'travelia_page_settings_register' );

function travelia_page_settings_register( $wp_customize ) {

	/**
     * Add Page Settings Panel
     *
     * @since 1.0.0
     */
    $wp_customize->add_panel(
       'travelia_page_settings_panel',
       array(
           'priority'       => 25,
           'capability'     => 'edit_theme_options',
           'theme_supports' => '',
           'title'          => __( 'Page Settings', 'travelia-pro' ),
       )
   );

    /*----------------------------------------------------------------------------------------------------------------------------------------*/
	/**
     * Contact Page section
     *
     * @since 1.0.0
     */
    $wp_customize->add_section(
        'travelia_contact_page_section',
        array(
        	'priority'       => 1,
        	'panel'          => 'travelia_page_settings_panel',
        	'capability'     => 'edit_theme_options',
        	'theme_supports' => '',
            'title'          => __( 'Contact Page', 'travelia-pro' ),
            'description'    => __( 'Managed the content display at contact page.', 'travelia-pro' ),
        )
    );

    $wp_customize->add_setting( 'travelia_contact_page_title', array(
        'capability'            => 'edit_theme_options',
        'default'               => '',
        'sanitize_callback'     => 'travelia_sanitize_dropdown_pages'
    ) );

    $wp_customize->add_control( 'travelia_contact_page_title', array( 
        'label'                 =>  __( 'Select Page for  contact Page title & description', 'travelia-pro' ),
        'section'               => 'travelia_contact_page_section',
        'type'                  => 'dropdown-pages',
        'settings'              => 'travelia_contact_page_title',
    ) );

    // Contact form
    $wp_customize->add_setting( 'travelia_contact_form_shortcode', array(
        'capability'            => 'edit_theme_options',
        'default'               => '',
        'sanitize_callback'     => 'sanitize_text_field'
    ) );

    $wp_customize->add_control( 'travelia_contact_form_shortcode', array(
        'label'                 =>  __( 'Use Shortcode for contact form', 'travelia-pro' ),
        'description'           =>  __( 'eg [contact-form-7 id="108" title="Contact form 1"]', 'travelia-pro' ),
        'section'               => 'travelia_contact_page_section',
        'type'                  => 'text',
        'settings' => 'travelia_contact_form_shortcode',
    ) );


    
    /** Contact Items */
    $wp_customize->add_setting( 
        new Travelia_Repeater_Setting( 
            $wp_customize, 
            'travelia_contact_items', 
            array(
                'default' => array(
                    array(
                        'icon' => 'fa fa-map-marker',
                        'title' => ' Road-7 old Street, Manhatan'   
                    ),
                    array(
                        'icon' => 'fa fa-phone',
                        'title' => '+2112-6546654'
                    ),
                    array(
                        'icon' => 'fa fa-envelope',
                        'title' => ' info@berater3.com'
                    )
                ),
                'sanitize_callback' => array( 'Travelia_Repeater_Setting', 'sanitize_repeater_setting' ),
            ) 
        ) 
    );

    $wp_customize->add_control(
        new Travelia_Control_Repeater(
            $wp_customize,
            'travelia_contact_items',
            array(
                'section' => 'travelia_contact_page_section',              
                'label'   => __( 'Contact items', 'travelia-pro' ),
                'fields'  => array(
                    'icon' => array(
                        'type'        => 'font',
                        'label'       => __( 'Font Awesome Icon', 'travelia-pro' ),
                        'description' => __( 'Example: fa-facebook', 'travelia-pro' ),
                    ),
                    'title' => array(
                        'type'        => 'text',
                        'label'       => __( 'Location Title', 'travelia-pro' ),
                    )
                ),
                'row_label' => array(
                    'type' => 'field',
                    'value' => __( 'contacts', 'travelia-pro' ),
                    'field' => 'title'
                )                        
            )
        )
    );


    /*----------------------------------------------------------------------------------------------------------------------------------------*/
    /**
     * Team Page Section
     *
     * @since 1.0.0
     */
    $wp_customize->add_section(
        'travelia_team_settings_section',
        array(
            'priority'       => 2,
            'panel'          => 'travelia_page_settings_panel',
            'capability'     => 'edit_theme_options',
            'theme_supports' => '',
            'title'          => __( 'Team Page Section', 'travelia-pro' )
        )
    );


    /** Team Title line heading */
    $wp_customize->add_setting(
        'travelia_team_heading_title',
        array(
            'default'           => __( 'Our Experties', 'travelia-pro' ),
            'sanitize_callback' => 'sanitize_text_field',
            'transport'         => 'postMessage'
        )
    );

    $wp_customize->add_control(
        'travelia_team_heading_title',
        array(
            'label'    => __( 'Team Heading Title', 'travelia-pro' ),
            'section'  => 'travelia_team_settings_section',
            'type'     => 'text',
        )
    );

    $wp_customize->selective_refresh->add_partial( 'travelia_team_heading_title', array(
        'selector' => '.team .title-line h2',
        'render_callback' => 'travelia_get_team_heading_title',
    ) );    


     /// Setting: Link of Service Custom Post Type.
    class Travelia_Team_Post_Type_Info extends WP_Customize_Control {
        public $type = 'customtext';
    public $extra = ''; // we add this for the extra description
    public function render_content() {
        ?>
        <label>            
            <a href="<?php echo esc_url( 'edit.php?post_type=team' ); ?>" target='_blank'><?php echo esc_html( $this->label ); ?></a>
            <span><?php echo esc_html( $this->extra ); ?></span>         
        </label>
        <?php
    }
}

$wp_customize->add_setting('travelia_team_post_type_info', array(
  'default' => '',
  'type' => 'customtext',
  'capability' => 'edit_theme_options',
  'transport' => 'refresh',
  'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( new Travelia_Team_Post_Type_Info( $wp_customize, 'travelia_team_post_type_info', array(
    'label' => esc_attr__( 'Go to Team Page', 'travelia-pro' ),
    'section' => 'travelia_team_settings_section',
    'settings' => 'travelia_team_post_type_info',
    'extra' => esc_attr__( ' for more info', 'travelia-pro' )
) ) 
);


/*----------------------------------------------------------------------------------------------------------------------------------------*/
    /**
     * About Page Section
     *
     * @since 1.0.0
     */
    $wp_customize->add_section(
        'travelia_about_settings_section',
        array(
            'priority'       => 3,
            'panel'          => 'travelia_page_settings_panel',
            'capability'     => 'edit_theme_options',
            'theme_supports' => '',
            'title'          => __( 'About Page Section', 'travelia-pro' )
        )
    );


    $wp_customize->add_setting( 'travelia_about_vedio_url', array(
        'capability'            => 'edit_theme_options',
        'default'               => '',
        'sanitize_callback'     => 'esc_url_raw'
    ) );

    $wp_customize->add_control( 'travelia_about_vedio_url', array( 
        'label'                 =>  __( 'Vedio Url', 'travelia-pro' ),
        'description'           => __('Only youtube vedio Link work properly','travelia-pro'),
        'section'               => 'travelia_about_settings_section',
        'type'                  => 'url',
        'settings'              => 'travelia_about_vedio_url',
    ) );
    $wp_customize->add_setting( 'travelia_about_button_1_title', array(
        'capability'            => 'edit_theme_options',
        'default'               => '',
        'sanitize_callback'     => 'sanitize_text_field'
    ) );

    $wp_customize->add_control( 'travelia_about_button_1_title', array(
        /* translators: %s: Description */ 
        'label'                 =>  sprintf( __( 'Button %s Title', 'travelia-pro' ), '1' ),
        'description'           =>  __( 'Our Blog', 'travelia-pro' ),
        'section'               => 'travelia_about_settings_section',
        'type'                  => 'text',
        'settings' => 'travelia_about_button_1_title',
    ) );

    $wp_customize->add_setting( 'travelia_about_button_1_url', array(
        'capability'            => 'edit_theme_options',
        'default'               => '',
        'sanitize_callback'     => 'esc_url_raw'
    ) );

    $wp_customize->add_control( 'travelia_about_button_1_url', array(
        /* translators: %s: Description */ 
        'label'                 =>  sprintf( __( 'Button   %s Url', 'travelia-pro' ), '1' ),
        'description'           =>  __( '#', 'travelia-pro' ),
        'section'               => 'travelia_about_settings_section',
        'type'                  => 'url',
        'settings' => 'travelia_about_button_1_url',
    ) );

    $wp_customize->add_setting( 'travelia_about_button_2_title', array(
        'capability'            => 'edit_theme_options',
        'default'               => '',
        'sanitize_callback'     => 'sanitize_text_field'
    ) );

    $wp_customize->add_control( 'travelia_about_button_2_title', array(
        /* translators: %s: Description */ 
        'label'                 =>  sprintf( __( 'Button %s title', 'travelia-pro' ), '2' ),
        'description'           =>  __( 'Contact Us', 'travelia-pro' ),
        'section'               => 'travelia_about_settings_section',
        'type'                  => 'text',
        'settings' => 'travelia_about_button_2_title',
    ) );

    $wp_customize->add_setting( 'travelia_about_button_2_url', array(
        'capability'            => 'edit_theme_options',
        'default'               => '',
        'sanitize_callback'     => 'esc_url_raw'
    ) );

    $wp_customize->add_control( 'travelia_about_button_2_url', array(
        /* translators: %s: Description */ 
        'label'                 =>  sprintf( __( 'Button %s Url', 'travelia-pro' ), '2' ),
        'description'           =>  __( '#', 'travelia-pro' ),
        'section'               => 'travelia_about_settings_section',
        'type'                  => 'url',
        'settings' => 'travelia_about_button_2_url',
    ) );

}