<?php
/**
 * Create the metabox
 * @link https://developer.wordpress.org/reference/functions/add_meta_box/
 */
function _team_create_metabox() {
	add_meta_box(
		'_team_metabox', // Metabox ID
		'Team Details', // Title to display
		'_team_render_metabox', // Function to call that contains the metabox content
		'team', // Post type to display metabox on
		'normal', // Where to put it (normal = main colum, side = sidebar, etc.)
		'default' // Priority relative to other metaboxes
	);
}
add_action( 'add_meta_boxes', '_team_create_metabox' );

/**
 * Create the metabox default values
 * This allows us to save multiple values in an array, reducing the size of our database.
 * Setting defaults helps avoid "array key doesn't exit" issues.
 * @todo
 */
function _team_metabox_defaults() {
	return array(
			'position' => '',
			'facebook_url' => '',
			'twitter_url' => '',
			'linkedin_url' => '',
			'behance_url' => '',
	);
}
/**
 * Render the metabox markup
 * This is the function called in `_team_create_metabox()`
 */
function _team_render_metabox($post) {
	
	$saved = get_post_meta( $post->ID, '_team', true ); // Get the saved values
	$defaults = _team_metabox_defaults(); // Get the default values
	$details = wp_parse_args( $saved, $defaults ); // Merge the two in case any fields don't exist in the saved data
	?>
		<fieldset>
			
			<div class="admin_metabox_section">
				<label for="_team_custom_metabox_position">
					<?php
						esc_attr_e( 'Position', "travelia-pro" );
					?>
				</label>
				<input
					type="text"
					name="_team_custom_metabox[position]"
					id="_team_custom_metabox_position"
					value="<?php echo esc_attr( $details['position'] ); ?>"
				>
			</div>

			<div class="admin_metabox_section">
				<label for="_team_custom_metabox_facebook_url">
					<?php
						esc_attr_e( 'Facebook Url', "travelia-pro" );
					?>
				</label>
			
				<input
					type="text"
					name="_team_custom_metabox[facebook_url]"
					id="_team_custom_metabox_facebook_url"
					value="<?php echo esc_url( $details['facebook_url'] ); ?>"
				>
			</div>	

			<div class="admin_metabox_section">
				<label for="_team_custom_metabox_twitter_url">
					<?php
						esc_attr_e( 'Twitter Url', "travelia-pro" );
					?>
				</label>
			
				<input
					type="text"
					name="_team_custom_metabox[twitter_url]"
					id="_team_custom_metabox_twitter_url"
					value="<?php echo esc_url( $details['twitter_url'] ); ?>"
				>
			</div>	

			<div class="admin_metabox_section">
				<label for="_team_custom_metabox_linkedin_url">
					<?php
						esc_attr_e( 'Linkedin', "travelia-pro" );
					?>
				</label>
			
				<input
					type="text"
					name="_team_custom_metabox[linkedin_url]"
					id="_team_custom_metabox_linkedin_url"
					value="<?php echo esc_url( $details['linkedin_url'] ); ?>"
				>
			</div>	

			<div class="admin_metabox_section">
				<label for="_team_custom_metabox_behance_url">
					<?php
						esc_attr_e( 'Behance Url', "travelia-pro" );
					?>
				</label>
				
				<input
					type="text"
					name="_team_custom_metabox[behance_url]"
					id="_team_custom_metabox_behance_url"
					value="<?php echo esc_url( $details['behance_url'] ); ?>"
				>
			</div>	

		</fieldset>

	<?php

	wp_nonce_field( '_team_form_metabox_nonce', '_team_form_metabox_process' );
}

//
// Save our data
//
/**
 * Save the metabox
 * @param  Number $post_id The post ID
 * @param  Array  $post    The post data
 */
function _team_save_metabox( $post_id, $post ) {
	// Verify that our security field exists. If not, bail.
	if ( !isset( $_POST['_team_form_metabox_process'] ) ) return;
	// Verify data came from edit/dashboard screen
	if ( !wp_verify_nonce( $_POST['_team_form_metabox_process'], '_team_form_metabox_nonce' ) ) {
		return $post->ID;
	}
	// Verify user has permission to edit post
	if ( !current_user_can( 'edit_post', $post->ID )) {
		return $post->ID;
	}
	// Check that our custom fields are being passed along
	// This is the `name` value array. We can grab all
	// of the fields and their values at once.
	if ( !isset( $_POST['_team_custom_metabox'] ) ) {
		return $post->ID;
	}
	/**
	 * Sanitize all data
	 * This keeps malicious code out of our database.
	 */
	// Set up an empty array
	$sanitized = array();
	// Loop through each of our fields
	foreach ( $_POST['_team_custom_metabox'] as $key => $detail ) {
		// Sanitize the data and push it to our new array
		// `wp_filter_post_kses` strips our dangerous server values
		// and allows through anything you can include a post.
		$sanitized[$key] = wp_filter_post_kses( $detail );
	}
	// Save our submissions to the database
	update_post_meta( $post->ID, '_team', $sanitized );
}
add_action( 'save_post', '_team_save_metabox', 1, 2 );
//
// Save a copy to our revision history
// This is optional, and potentially undesireable for certain data types.
// Restoring a a post to an old version will also update the metabox.
/**
 * Save events data to revisions
 * @param  Number $post_id The post ID
 */
function _team_save_revisions( $post_id ) {
	// Check if it's a revision
	$parent_id = wp_is_post_revision( $post_id );
	// If is revision
	if ( $parent_id ) {
		// Get the saved data
		$parent = get_post( $parent_id );
		$details = get_post_meta( $parent->ID, '_team', true );
		// If data exists and is an array, add to revision
		if ( !empty( $details ) && is_array( $details ) ) {
			// Get the defaults
			$defaults = _team_metabox_defaults();
			// For each default item
			foreach ( $defaults as $key => $value ) {
				// If there's a saved value for the field, save it to the version history
				if ( array_key_exists( $key, $details ) ) {
					add_metadata( 'post', $post_id, '_team_' . $key, $details[$key] );
				}
			}
		}
	}
}
add_action( 'save_post', '_team_save_revisions' );
/**
 * Restore events data with post revisions
 * @param  Number $post_id     The post ID
 * @param  Number $revision_id The revision ID
 */
function _team_restore_revisions( $post_id, $revision_id ) {
	// Variables
	$post = get_post( $post_id ); // The post
	$revision = get_post( $revision_id ); // The revision
	$defaults = _team_metabox_defaults(); // The default values
	$details = array(); // An empty array for our new metadata values
	// Update content
	// For each field
	foreach ( $defaults as $key => $value ) {
		// Get the revision history version
		$detail_revision = get_metadata( 'post', $revision->ID, '_team_' . $key, true );
		// If a historic version exists, add it to our new data
		if ( isset( $detail_revision ) ) {
			$details[$key] = $detail_revision;
		}
	}
	// Replace our saved data with the old version
	update_post_meta( $post_id, '_team', $details );
}
add_action( 'wp_restore_post_revision', '_team_restore_revisions', 10, 2 );
/**
 * Get the data to display on the revisions page
 * @param  Array $fields The fields
 * @return Array The fields
 */
function _team_get_revisions_fields( $fields ) {
	// Get our default values
	$defaults = _team_metabox_defaults();
	// For each field, use the key as the title
	foreach ( $defaults as $key => $value ) {
		$fields['_team_' . $key] = ucfirst( $key );
	}
	return $fields;
}
add_filter( '_wp_post_revision_fields', '_team_get_revisions_fields' );
/**
 * Display the data on the revisions page
 * @param  String|Array $value The field value
 * @param  Array        $field The field
 */
function _team_display_revisions_fields( $value, $field ) {
	global $revision;
	return get_metadata( 'post', $revision->ID, $field, true );
}
add_filter( '_wp_post_revision_field_my_meta', '_team_display_revisions_fields', 10, 2 );
